@@ -29,13 +29,12 @@
 #include "xfburn-progress-dialog.h"
 #include "xfburn-device-box.h"
 #include "xfburn-device-list.h"
-#include "xfburn-stock.h"
 #include "xfburn-udev-manager.h"
 #include "xfburn-main.h"
 
 #include "xfburn-blank-dialog.h"
 
-#define XFBURN_BLANK_DIALOG_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE ((obj), XFBURN_TYPE_BLANK_DIALOG, XfburnBlankDialogPrivate))
+#define XFBURN_BLANK_DIALOG_GET_PRIVATE(obj) (xfburn_blank_dialog_get_instance_private (obj))
 
 #define XFBURN_BLANK_DIALOG_EJECT_DEFAULT TRUE
 
@@ -91,8 +90,6 @@ typedef struct {
 
 /* internal prototypes */
 
-static void xfburn_blank_dialog_class_init (XfburnBlankDialogClass * klass);
-static void xfburn_blank_dialog_init (XfburnBlankDialog * sp);
 static void xfburn_blank_dialog_get_property (GObject *object, guint prop_id, GValue *value, GParamSpec *pspec);
 static void xfburn_blank_dialog_set_property (GObject *object, guint prop_id, const GValue *value, GParamSpec *pspec);
 
@@ -101,38 +98,13 @@ static void fill_combo_mode (XfburnBlankDialog *dialog);
 //static GList * get_valid_blank_modes (XfburnDevice *device);
 static XfburnBlankMode get_selected_mode (XfburnBlankDialogPrivate *priv);
 static gboolean thread_blank_perform_blank (ThreadBlankParams * params, struct burn_drive_info *drive_info);
-static void thread_blank (ThreadBlankParams * params);
+static void* thread_blank (ThreadBlankParams * params);
 static void xfburn_blank_dialog_response_cb (XfburnBlankDialog * dialog, gint response_id, gpointer user_data);
 static void cb_volume_changed (GtkWidget *device_box, gboolean device_changed, XfburnDevice *device, XfburnBlankDialog * dialog);
 
 static XfceTitledDialogClass *parent_class = NULL;
 
-
-
-GType
-xfburn_blank_dialog_get_type (void)
-{
-  static GType type = 0;
-
-  if (type == 0) {
-    static const GTypeInfo our_info = {
-      sizeof (XfburnBlankDialogClass),
-      NULL,
-      NULL,
-      (GClassInitFunc) xfburn_blank_dialog_class_init,
-      NULL,
-      NULL,
-      sizeof (XfburnBlankDialog),
-      0,
-      (GInstanceInitFunc) xfburn_blank_dialog_init,
-      NULL,
-    };
-
-    type = g_type_register_static (XFCE_TYPE_TITLED_DIALOG, "XfburnBlankDialog", &our_info, 0);
-  }
-
-  return type;
-}
+G_DEFINE_TYPE_WITH_PRIVATE(XfburnBlankDialog, xfburn_blank_dialog, XFCE_TYPE_TITLED_DIALOG);
 
 static void
 xfburn_blank_dialog_class_init (XfburnBlankDialogClass * klass)
@@ -143,8 +115,6 @@ xfburn_blank_dialog_class_init (XfburnBlankDialogClass * klass)
   object_class->set_property = xfburn_blank_dialog_set_property;
   object_class->get_property = xfburn_blank_dialog_get_property;
   
-  g_type_class_add_private (klass, sizeof (XfburnBlankDialogPrivate));
-
   g_object_class_install_property (object_class, PROP_EJECT, 
                                    g_param_spec_boolean ("eject", _("Eject the disc"),
                                                         _("Default value for eject checkbox"), XFBURN_BLANK_DIALOG_EJECT_DEFAULT, G_PARAM_READWRITE));
@@ -153,7 +123,7 @@ xfburn_blank_dialog_class_init (XfburnBlankDialogClass * klass)
 static void
 xfburn_blank_dialog_get_property (GObject *object, guint prop_id, GValue *value, GParamSpec *pspec)
 {
-  XfburnBlankDialogPrivate *priv = XFBURN_BLANK_DIALOG_GET_PRIVATE (object);
+  XfburnBlankDialogPrivate *priv = XFBURN_BLANK_DIALOG_GET_PRIVATE (XFBURN_BLANK_DIALOG (object));
 
   switch (prop_id) {
     case PROP_EJECT:
@@ -168,7 +138,7 @@ xfburn_blank_dialog_get_property (GObject *object, guint prop_id, GValue *value,
 static void
 xfburn_blank_dialog_set_property (GObject *object, guint prop_id, const GValue *value, GParamSpec *pspec)
 {
-  XfburnBlankDialogPrivate *priv = XFBURN_BLANK_DIALOG_GET_PRIVATE (object);
+  XfburnBlankDialogPrivate *priv = XFBURN_BLANK_DIALOG_GET_PRIVATE (XFBURN_BLANK_DIALOG (object));
   
   switch (prop_id) {
     case PROP_EJECT:
@@ -185,11 +155,12 @@ static void
 xfburn_blank_dialog_init (XfburnBlankDialog * obj)
 {
   XfburnBlankDialogPrivate *priv = XFBURN_BLANK_DIALOG_GET_PRIVATE (obj);
-  GtkBox *box = GTK_BOX (GTK_DIALOG (obj)->vbox);
+  GtkBox *box = GTK_BOX (gtk_dialog_get_content_area((GTK_DIALOG (obj))));
   GdkPixbuf *icon = NULL;
   GtkWidget *frame;
   GtkWidget *vbox;
   GtkWidget *button;
+  gint x,y;
 
   GtkListStore *store = NULL;
   GtkCellRenderer *cell;
@@ -197,7 +168,9 @@ xfburn_blank_dialog_init (XfburnBlankDialog * obj)
   gtk_window_set_title (GTK_WINDOW (obj), _("Blank Disc"));
   gtk_window_set_destroy_with_parent (GTK_WINDOW (obj), TRUE);
   
-  icon = gtk_widget_render_icon (GTK_WIDGET (obj), XFBURN_STOCK_BLANK_CDRW, GTK_ICON_SIZE_DIALOG, NULL);
+  gtk_icon_size_lookup (GTK_ICON_SIZE_DIALOG, &x, &y);
+  icon = gtk_icon_theme_load_icon ( gtk_icon_theme_get_default(), "stock_xfburn-blank-cdrw", x, GTK_ICON_LOOKUP_GENERIC_FALLBACK, NULL);
+
   gtk_window_set_icon (GTK_WINDOW (obj), icon);
   g_object_unref (icon);
 
@@ -224,7 +197,7 @@ xfburn_blank_dialog_init (XfburnBlankDialog * obj)
   gtk_box_pack_start (box, frame, FALSE, FALSE, BORDER);
 
   /* options */
-  vbox = gtk_vbox_new (FALSE, 0);
+  vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
   gtk_widget_show (vbox);
 
   frame = xfce_gtk_frame_box_new_with_content (_("Options"), vbox);
@@ -237,14 +210,14 @@ xfburn_blank_dialog_init (XfburnBlankDialog * obj)
   gtk_box_pack_start (GTK_BOX (vbox), priv->check_eject, FALSE, FALSE, BORDER);
 
   /* action buttons */
-  button = gtk_button_new_from_stock (GTK_STOCK_CANCEL);
+  button = gtk_button_new_with_mnemonic ("_Cancel");
   gtk_widget_show (button);
   gtk_dialog_add_action_widget (GTK_DIALOG (obj), button, GTK_RESPONSE_CANCEL);
 
-  button = xfburn_gtk_button_new_mixed (XFBURN_STOCK_BLANK_CDRW, _("_Blank"));
+  button = xfce_gtk_button_new_mixed ("stock_xfburn-blank-cdrw", _("_Blank"));
   gtk_widget_show (button);
   gtk_dialog_add_action_widget (GTK_DIALOG (obj), button, GTK_RESPONSE_OK);
-  GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
+  gtk_widget_set_can_default (button, TRUE);
   gtk_widget_grab_focus (button);
   gtk_widget_grab_default (button);
   priv->button_blank = button;
@@ -350,12 +323,12 @@ thread_blank_perform_blank (ThreadBlankParams * params, struct burn_drive_info *
     usleep (1001);
 
   switch (disc_state) {
-  case BURN_DISC_BLANK:
+  case BURN_DISC_BLANK: 
     if (params->blank_mode == XFBURN_BLANK_FAST || params->blank_mode == XFBURN_BLANK_COMPLETE) {
       /* blanking can only be performed on blank discs, format and deformat are allowed to be blank ones */
       xfburn_progress_dialog_burning_failed (XFBURN_PROGRESS_DIALOG (dialog_progress), _("The inserted disc is already blank."));
       return FALSE;
-    }
+    } // fall through
   case BURN_DISC_FULL:
   case BURN_DISC_APPENDABLE:
     /* these ones we can blank */
@@ -452,7 +425,7 @@ thread_blank_perform_blank (ThreadBlankParams * params, struct burn_drive_info *
   return TRUE;
 }
 
-static void
+static void*
 thread_blank (ThreadBlankParams * params)
 {
   struct burn_drive_info *drive_info = NULL;
@@ -472,6 +445,7 @@ thread_blank (ThreadBlankParams * params)
   xfburn_udev_manager_send_volume_changed ();
   gdk_threads_leave ();
 #endif
+  return NULL;
 }
 
 static XfburnBlankMode
@@ -527,8 +501,6 @@ xfburn_blank_dialog_response_cb (XfburnBlankDialog * dialog, gint response_id, g
 static void
 cb_volume_changed (GtkWidget *device_box, gboolean device_changed, XfburnDevice *device, XfburnBlankDialog * dialog)
 {
-  //XfburnBlankDialogPrivate *priv = XFBURN_BLANK_DIALOG_GET_PRIVATE (dialog);
-
   fill_combo_mode (dialog);
 }
 
