@@ -33,7 +33,6 @@
 #include "xfburn-global.h"
 #include "xfburn-utils.h"
 #include "xfburn-settings.h"
-#include "xfburn-stock.h"
 #include "xfburn-settings.h"
 
 #include "xfburn-device-box.h"
@@ -41,7 +40,7 @@
 #include "xfburn-progress-dialog.h"
 #include "xfburn-perform-burn.h"
 
-#define XFBURN_BURN_DATA_COMPOSITION_BASE_DIALOG_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE ((obj), XFBURN_TYPE_BURN_DATA_COMPOSITION_BASE_DIALOG, XfburnBurnDataCompositionBaseDialogPrivate))
+#define XFBURN_BURN_DATA_COMPOSITION_BASE_DIALOG_GET_PRIVATE(obj) (xfburn_burn_data_composition_base_dialog_get_instance_private (XFBURN_BURN_DATA_COMPOSITION_BASE_DIALOG(obj)))
 
 typedef struct
 {
@@ -91,8 +90,6 @@ char *proceed_image[] = {
 */
 
 /* prototypes */
-static void xfburn_burn_data_composition_base_dialog_class_init (XfburnBurnDataCompositionBaseDialogClass * klass);
-static GObject * xfburn_burn_data_composition_base_dialog_constructor (GType type, guint n_construct_properties, GObjectConstructParam *construct_properties);
 static void xfburn_burn_data_composition_base_dialog_finalize (GObject * object);
 
 static void xfburn_burn_data_composition_base_dialog_get_property (GObject * object, guint prop_id, GValue * value, GParamSpec * pspec);
@@ -113,30 +110,7 @@ static void cb_dialog_response (XfburnBurnDataCompositionBaseDialog * dialog, gi
 /* globals */
 static XfceTitledDialogClass *parent_class = NULL;
 
-GType
-xfburn_burn_data_composition_base_dialog_get_type (void)
-{
-  static GType type = 0;
-
-  if (type == 0) {
-    static const GTypeInfo our_info = {
-      sizeof (XfburnBurnDataCompositionBaseDialogClass),
-      NULL,
-      NULL,
-      (GClassInitFunc) xfburn_burn_data_composition_base_dialog_class_init,
-      NULL,
-      NULL,
-      sizeof (XfburnBurnDataCompositionBaseDialog),
-      0,
-      NULL,
-      NULL
-    };
-
-    type = g_type_register_static (XFCE_TYPE_TITLED_DIALOG, "XfburnBurnDataCompositionBaseDialog", &our_info, 0);
-  }
-
-  return type;
-}
+G_DEFINE_TYPE_WITH_PRIVATE (XfburnBurnDataCompositionBaseDialog, xfburn_burn_data_composition_base_dialog, XFCE_TYPE_TITLED_DIALOG)
 
 static void
 xfburn_burn_data_composition_base_dialog_class_init (XfburnBurnDataCompositionBaseDialogClass * klass)
@@ -144,9 +118,7 @@ xfburn_burn_data_composition_base_dialog_class_init (XfburnBurnDataCompositionBa
   GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
   parent_class = g_type_class_peek_parent (klass);
-  g_type_class_add_private (klass, sizeof (XfburnBurnDataCompositionBaseDialogPrivate));
   
-  object_class->constructor = xfburn_burn_data_composition_base_dialog_constructor;
   object_class->finalize = xfburn_burn_data_composition_base_dialog_finalize;
   object_class->get_property = xfburn_burn_data_composition_base_dialog_get_property;
   object_class->set_property = xfburn_burn_data_composition_base_dialog_set_property;
@@ -158,13 +130,10 @@ xfburn_burn_data_composition_base_dialog_class_init (XfburnBurnDataCompositionBa
 				   g_param_spec_boolean ("show-volume-name", _("Show volume name"), _("Show a text entry for the name of the volume"), FALSE, G_PARAM_CONSTRUCT_ONLY | G_PARAM_READWRITE));
 }
 
-static GObject *
-xfburn_burn_data_composition_base_dialog_constructor (GType type, guint n_construct_properties, GObjectConstructParam *construct_properties)
+static void
+xfburn_burn_data_composition_base_dialog_init(XfburnBurnDataCompositionBaseDialog *obj)
 {
-  GObject *gobj;
-  XfburnBurnDataCompositionBaseDialog *obj;
-  XfburnBurnDataCompositionBaseDialogPrivate *priv;
-  
+  XfburnBurnDataCompositionBaseDialogPrivate *priv = xfburn_burn_data_composition_base_dialog_get_instance_private(obj);
   GdkPixbuf *icon = NULL;
   GtkBox *box;
   GtkWidget *img;
@@ -175,15 +144,15 @@ xfburn_burn_data_composition_base_dialog_constructor (GType type, guint n_constr
   gchar *default_path;
   gchar *tmp_dir;
   const char *comp_name;
+  gint x,y;
 
-  gobj = G_OBJECT_CLASS (parent_class)->constructor (type, n_construct_properties, construct_properties);
-  obj = XFBURN_BURN_DATA_COMPOSITION_BASE_DIALOG (gobj);
-  priv = XFBURN_BURN_DATA_COMPOSITION_BASE_DIALOG_GET_PRIVATE (obj);
-  box = GTK_BOX (GTK_DIALOG (obj)->vbox);
+  box = GTK_BOX (gtk_dialog_get_content_area((GTK_DIALOG (obj))));
 
   gtk_window_set_title (GTK_WINDOW (obj), _("Burn Composition"));
   gtk_window_set_destroy_with_parent (GTK_WINDOW (obj), TRUE);
-  icon = gtk_widget_render_icon (GTK_WIDGET (obj), XFBURN_STOCK_BURN_CD, GTK_ICON_SIZE_DIALOG, NULL);
+  gtk_icon_size_lookup (GTK_ICON_SIZE_DIALOG, &x, &y);
+  icon = gtk_icon_theme_load_icon ( gtk_icon_theme_get_default(), "stock_xfburn", x, GTK_ICON_LOOKUP_GENERIC_FALLBACK, NULL);
+
   gtk_window_set_icon (GTK_WINDOW (obj), icon);
   g_object_unref (icon);
 
@@ -198,10 +167,10 @@ xfburn_burn_data_composition_base_dialog_constructor (GType type, guint n_constr
   gtk_box_pack_start (box, priv->frame_device, FALSE, FALSE, BORDER);
 
   /* composition name */
-  comp_name = iso_image_get_volume_id (priv->image);
   if (priv->show_volume_name) {
     GtkWidget *label;
-    vbox = gtk_vbox_new (FALSE, 0);
+    comp_name = iso_image_get_volume_id (priv->image);
+    vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
     gtk_widget_show (vbox);
 
     frame = xfce_gtk_frame_box_new_with_content (_("Composition name"), vbox);
@@ -222,7 +191,7 @@ xfburn_burn_data_composition_base_dialog_constructor (GType type, guint n_constr
   }
 
   /* options */
-  vbox = gtk_vbox_new (FALSE, 0);
+  vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
   gtk_widget_show (vbox);
 
   frame = xfce_gtk_frame_box_new_with_content (_("Options"), vbox);
@@ -253,15 +222,15 @@ xfburn_burn_data_composition_base_dialog_constructor (GType type, guint n_constr
   gtk_widget_show (priv->check_only_iso);
   gtk_box_pack_start (GTK_BOX (vbox), priv->check_only_iso, FALSE, FALSE, BORDER);
   g_signal_connect (G_OBJECT (priv->check_only_iso), "toggled", G_CALLBACK (cb_check_only_iso_toggled), obj);
-
+/*
   align = gtk_alignment_new (0, 0, 0, 0);
   gtk_alignment_set_padding (GTK_ALIGNMENT (align), 0, 0, BORDER * 4, 0);
   gtk_widget_show (align);
   gtk_box_pack_start (GTK_BOX (vbox), align, FALSE, FALSE, 0);
-
-  priv->hbox_iso = gtk_hbox_new (FALSE, 0);
+*/
+  priv->hbox_iso = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, BORDER*4);
   gtk_widget_show (priv->hbox_iso);
-  gtk_container_add (GTK_CONTAINER (align), priv->hbox_iso);
+  gtk_container_add (GTK_CONTAINER(vbox), priv->hbox_iso);
   gtk_widget_set_sensitive (priv->hbox_iso, FALSE);
 
   priv->entry_path_iso = gtk_entry_new ();
@@ -273,7 +242,7 @@ xfburn_burn_data_composition_base_dialog_constructor (GType type, guint n_constr
   gtk_widget_show (priv->entry_path_iso);
   gtk_box_pack_start (GTK_BOX (priv->hbox_iso), priv->entry_path_iso, FALSE, FALSE, 0);
 
-  img = gtk_image_new_from_stock (GTK_STOCK_DIRECTORY, GTK_ICON_SIZE_SMALL_TOOLBAR);
+  img = gtk_image_new_from_icon_name ("folder", GTK_ICON_SIZE_SMALL_TOOLBAR);
   gtk_widget_show (img);
   button = gtk_button_new ();
   gtk_container_add (GTK_CONTAINER (button), img);
@@ -282,11 +251,11 @@ xfburn_burn_data_composition_base_dialog_constructor (GType type, guint n_constr
   g_signal_connect (G_OBJECT (button), "clicked", G_CALLBACK (cb_browse_iso), obj);
 
   /* action buttons */
-  button = gtk_button_new_from_stock (GTK_STOCK_CANCEL);
+  button = gtk_button_new_with_mnemonic ("_Cancel");
   gtk_widget_show (button);
   gtk_dialog_add_action_widget (GTK_DIALOG (obj), button, GTK_RESPONSE_CANCEL);
 
-  priv->button_proceed = button = xfburn_gtk_button_new_mixed (XFBURN_STOCK_BURN_CD, _("_Burn Composition"));
+  priv->button_proceed = button = xfce_gtk_button_new_mixed ("stock_xfburn", _("_Burn Composition"));
   /*
    * Disabled: change button_proceed functionality
   button = create_proceed_button (obj, "xfburn-burn-cd", "");
@@ -296,14 +265,12 @@ xfburn_burn_data_composition_base_dialog_constructor (GType type, guint n_constr
   gtk_widget_show (button);
   gtk_dialog_add_action_widget (GTK_DIALOG (obj), button, GTK_RESPONSE_OK);
   //gtk_box_pack_start (GTK_BOX (GTK_DIALOG(obj)->action_area), button, TRUE, TRUE, 0);
-  GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
+  gtk_widget_set_can_default (button, TRUE);
   gtk_widget_grab_focus (button);
   gtk_widget_grab_default (button);
 
   cb_volume_changed (XFBURN_DEVICE_BOX (priv->device_box), TRUE, xfburn_device_box_get_selected_device (XFBURN_DEVICE_BOX (priv->device_box)), obj);
   g_signal_connect (G_OBJECT (obj), "response", G_CALLBACK (cb_dialog_response), priv);
-
-  return gobj;
 }
 
 static void
@@ -366,7 +333,7 @@ create_proceed_button (XfburnBurnDataCompositionBaseDialog * dialog, const gchar
   gtk_label_set_mnemonic_widget (GTK_LABEL (label), button);
 
   priv->image_proceed = image = gtk_image_new_from_stock (stock, GTK_ICON_SIZE_BUTTON);
-  hbox = gtk_hbox_new (FALSE, 2);
+  hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 2);
 
   align = gtk_alignment_new (0.5, 0.5, 0.0, 0.0);
 
@@ -455,7 +422,7 @@ typedef struct {
   gchar *iso_path;
 } ThreadWriteIsoParams;
 
-static void
+static void*
 thread_write_iso (ThreadWriteIsoParams * params)
 {
   GtkWidget *dialog_progress = params->dialog_progress;
@@ -524,6 +491,7 @@ thread_write_iso (ThreadWriteIsoParams * params)
   burn_source_free (params->src);
   g_free (params->iso_path);
   g_free (params);
+  return NULL;
 }
 
 typedef struct {
@@ -605,7 +573,7 @@ thread_burn_prep_and_burn (ThreadBurnCompositionParams * params, struct burn_dri
   burn_write_opts_free (burn_options);
 }
 
-static void
+static void*
 thread_burn_composition (ThreadBurnCompositionParams * params)
 {
   GtkWidget *dialog_progress = params->dialog_progress;
@@ -633,6 +601,7 @@ thread_burn_composition (ThreadBurnCompositionParams * params)
   burn_source_free (params->src);
 
   g_free (params);
+  return NULL;
 }
 
 static void
