@@ -94,10 +94,10 @@ static guint signals[LAST_SIGNAL];
 /*- class setup -*/
 /*****************/
 
-G_DEFINE_TYPE (XfburnDeviceList, xfburn_device_list, G_TYPE_OBJECT)
+G_DEFINE_TYPE_WITH_PRIVATE (XfburnDeviceList, xfburn_device_list, G_TYPE_OBJECT)
 
 #define GET_PRIVATE(o) \
-  (G_TYPE_INSTANCE_GET_PRIVATE ((o), XFBURN_TYPE_DEVICE_LIST, XfburnDeviceListPrivate))
+  (xfburn_device_list_get_instance_private (XFBURN_DEVICE_LIST (o)))
 
 static void
 xfburn_device_list_get_property (GObject *object, guint property_id,
@@ -174,8 +174,7 @@ xfburn_device_list_finalize (GObject *object)
   XfburnDeviceList *devlist = XFBURN_DEVICE_LIST (object);
   XfburnDeviceListPrivate *priv = GET_PRIVATE (devlist);
 
-  g_list_foreach (priv->devices, (GFunc) g_object_unref, NULL);
-  g_list_free (priv->devices);
+  g_list_free_full (priv->devices, (GDestroyNotify) g_object_unref);
 
   G_OBJECT_CLASS (parent_class)->finalize (object);
 }
@@ -186,7 +185,6 @@ xfburn_device_list_class_init (XfburnDeviceListClass *klass)
   GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
   parent_class = g_type_class_peek_parent (klass);
-  g_type_class_add_private (klass, sizeof (XfburnDeviceListPrivate));
 
   object_class->get_property = xfburn_device_list_get_property;
   object_class->set_property = xfburn_device_list_set_property;
@@ -413,7 +411,7 @@ xfburn_device_list_get_device_combo (XfburnDeviceList *devlist)
   GtkListStore *store = NULL;
   GtkCellRenderer *cell;
 
-  int i, selected;
+  int i, selected=-1;
 
   store = gtk_list_store_new (DEVICE_N_COLUMNS, G_TYPE_STRING, G_TYPE_POINTER);
   combo_device = gtk_combo_box_new_with_model (GTK_TREE_MODEL (store));
@@ -458,7 +456,7 @@ xfburn_device_list_get_refresh_button (XfburnDeviceList *devlist)
   XfburnDeviceListPrivate *priv = GET_PRIVATE (devlist);
   GtkWidget *img, *button;
 
-  img = gtk_image_new_from_stock (GTK_STOCK_REFRESH, GTK_ICON_SIZE_SMALL_TOOLBAR);
+  img = gtk_image_new_from_icon_name ("view-refresh", GTK_ICON_SIZE_SMALL_TOOLBAR);
   gtk_widget_show (img);
   button = gtk_button_new ();
   gtk_container_add (GTK_CONTAINER (button), img);
