@@ -5,12 +5,12 @@
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU Library General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
@@ -39,21 +39,20 @@
 #include "xfburn-progress-dialog.h"
 #include "xfburn-settings.h"
 #include "xfburn-main.h"
-#include "xfburn-stock.h"
 #include "xfburn-utils.h"
 
-#define XFBURN_MAIN_WINDOW_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE ((obj), XFBURN_TYPE_MAIN_WINDOW, XfburnMainWindowPrivate))
+#define XFBURN_MAIN_WINDOW_GET_PRIVATE(obj) (xfburn_main_window_get_instance_private(obj))
 
 /* private struct */
-typedef struct {  
-  GtkActionGroup *action_group;
-  GtkUIManager *ui_manager;
+typedef struct {
+  GSimpleActionGroup *action_map;
+  GtkBuilder *ui_manager;
 
   GtkWidget *menubar;
   GtkWidget *toolbars;
-  
+
   GtkWidget *vpaned;
-  
+
   GtkWidget *file_browser;
   GtkWidget *compositions_notebook;
 
@@ -62,87 +61,118 @@ typedef struct {
 } XfburnMainWindowPrivate;
 
 /* prototypes */
-static void xfburn_main_window_class_init (XfburnMainWindowClass *);
+G_DEFINE_TYPE_WITH_PRIVATE (XfburnMainWindow, xfburn_main_window, GTK_TYPE_WINDOW)
+
 static void xfburn_main_window_finalize (GObject *obj);
-static void xfburn_main_window_init (XfburnMainWindow *);
 
 static gboolean cb_delete_main_window (XfburnMainWindow *, GdkEvent *, XfburnMainWindowPrivate *);
-static void cb_edit_toolbars_view (ExoToolbarsView *, gpointer);
+// static void cb_edit_toolbars_view (ExoToolbarsView *, gpointer);
 
-static void action_about (GtkAction *, XfburnMainWindow *);
-static void action_preferences (GtkAction *, XfburnMainWindow *);
+static void action_about (GAction *, GVariant*, XfburnMainWindow *);
+static void action_preferences (GAction *, GVariant*, XfburnMainWindow *);
 
-static void action_new_data_composition (GtkAction *, XfburnMainWindow *);
-static void action_new_audio_composition (GtkAction *, XfburnMainWindow *);
+static void action_new_data_composition (GAction *, GVariant*, XfburnMainWindow *);
+static void action_new_audio_composition (GAction *, GVariant*, XfburnMainWindow *);
 
 /*
 static void action_load (GtkAction *, XfburnMainWindow *);
 static void action_save (GtkAction *, XfburnMainWindow *);
 static void action_save_as (GtkAction *, XfburnMainWindow *);
 */
-static void action_close (GtkAction *, XfburnMainWindow *);
-static void action_quit (GtkAction *, XfburnMainWindow *);
+static void action_close (GAction *, GVariant*, XfburnMainWindow *);
+static void action_quit (GAction *, GVariant*, XfburnMainWindow *);
 
-static void action_blank (GtkAction *, XfburnMainWindow *);
-static void action_copy_cd (GtkAction *, XfburnMainWindow *);
-static void action_burn_image (GtkAction *, XfburnMainWindow *);
+static void action_blank (GAction *, GVariant*, XfburnMainWindow *);
+static void action_copy_cd (GAction *, GVariant*, XfburnMainWindow *);
+static void action_burn_image (GAction *, GVariant*, XfburnMainWindow *);
 
 //static void action_copy_dvd (GtkAction *, XfburnMainWindow *);
-static void action_burn_dvd_image (GtkAction *, XfburnMainWindow *);
+static void action_burn_dvd_image (GAction *, GVariant*, XfburnMainWindow *);
 
-static void action_refresh_directorybrowser (GtkAction *, XfburnMainWindow *);
-static void action_show_filebrowser (GtkToggleAction *, XfburnMainWindow *);
-static void action_show_toolbar (GtkToggleAction * action, XfburnMainWindow * window);
+static void action_refresh_directorybrowser (GAction *, GVariant*, XfburnMainWindow *);
+static void action_show_filebrowser (GSimpleAction *, GVariant*, XfburnMainWindow *);
+static void action_show_toolbar (GSimpleAction * action, GVariant*, XfburnMainWindow * window);
 
 /* globals */
 static GtkWindowClass *parent_class = NULL;
-static const GtkActionEntry action_entries[] = {
+// upgrade to
+static const GActionEntry action_entries[] = {
+  // { "file-menu", NULL},
+  { .name = "new-data-composition", .activate = (gActionCallback)action_new_data_composition },
+  { .name = "new-audio-composition", .activate = (gActionCallback)action_new_audio_composition},
+  { .name = "close-composition", .activate = (gActionCallback)action_close},
+  { .name = "quit", .activate = (gActionCallback)action_quit},
+  // { .name = "edit-menu", .activate = NULL},
+  { .name = "preferences", .activate = (gActionCallback)action_preferences},
+  // { "action-menu", NULL},
+  { .name = "refresh", .activate = (gActionCallback)action_refresh_directorybrowser},
+  // { "help-menu", .activate = NULL},
+  { .name = "about", .activate = (gActionCallback)action_about},
+  { .name = "blank-disc", .activate = (gActionCallback)action_blank},
+  { .name = "copy-data", .activate = (gActionCallback)action_copy_cd},
+  { .name = "burn-image", .activate = (gActionCallback)action_burn_image},
+  { .name = "burn-dvd", .activate = (gActionCallback)action_burn_dvd_image},
+};
+
+static const struct {
+  const gchar * target;
+  const gchar * accel[2];
+} accelerator[] = {
+  {"new-data-composition",{"<Control><Alt>e",NULL}},
+  {"new-audio-composition",{"<Control><Alt>A",NULL}},
+};
+
+/*static const GtkActionEntry action_entries[] = {
   {"file-menu", NULL, N_("_File"), NULL, NULL, NULL},
-  /*{"new-composition", GTK_STOCK_NEW, N_("_New composition"), "", N_("Create a new composition"),},*/
-  /*{"new-composition", GTK_STOCK_NEW, N_("_New composition"), NULL, N_("Create a new composition"), 
+  /*{"new-composition", "document-new", N_("_New composition"), "", N_("Create a new composition"),},*/
+  /*{"new-composition", "document-new", N_("_New composition"), NULL, N_("Create a new composition"),
     G_CALLBACK (action_new_data_composition),}, */
-  {"new-data-composition", XFBURN_STOCK_NEW_DATA_COMPOSITION, N_("New data composition"), "<Control><Alt>e", N_("New data composition"),
+/*  {"new-data-composition", "xfburn-new-data-composition", N_("New data composition"), "<Control><Alt>e", N_("New data composition"),
     G_CALLBACK (action_new_data_composition),},
-  {"new-audio-composition", XFBURN_STOCK_AUDIO_CD, N_("New audio composition"), "<Control><Alt>A", N_("New audio composition"),
+  {"new-audio-composition", "xfburn-audio-cd", N_("New audio composition"), "<Control><Alt>A", N_("New audio composition"),
     G_CALLBACK (action_new_audio_composition),},
-  /*{"load-composition", GTK_STOCK_OPEN, N_("Load composition"), NULL, N_("Load composition"),
+  /*{"load-composition", "document-open", N_("Load composition"), NULL, N_("Load composition"),
    G_CALLBACK (action_load),},
-  {"save-composition", GTK_STOCK_SAVE, N_("Save composition"), NULL, N_("Save composition"), 
+  {"save-composition", "document-save", N_("Save composition"), NULL, N_("Save composition"),
    G_CALLBACK (action_save),},
-  {"save-composition-as", GTK_STOCK_SAVE_AS, N_("Save composition as..."), NULL, N_("Save composition as"), 
+  {"save-composition-as", "document-save"_AS, N_("Save composition as..."), NULL, N_("Save composition as"),
    G_CALLBACK (action_save_as),},*/
-  {"close-composition", GTK_STOCK_CLOSE, N_("Close composition"), NULL, N_("Close composition"), 
+/*  {"close-composition", "window-close", N_("Close composition"), NULL, N_("Close composition"),
    G_CALLBACK (action_close),},
-  {"quit", GTK_STOCK_QUIT, N_("_Quit"), NULL, N_("Quit Xfburn"), G_CALLBACK (action_quit),},
+  {"quit", "application-exit", N_("_Quit"), NULL, N_("Quit Xfburn"), G_CALLBACK (action_quit),},
   {"edit-menu", NULL, N_("_Edit"), NULL, NULL, NULL},
-  {"preferences", GTK_STOCK_PREFERENCES, N_("Prefere_nces"), NULL, N_("Show preferences dialog"),
+  {"preferences", "preferences-system", N_("Prefere_nces"), NULL, N_("Show preferences dialog"),
    G_CALLBACK (action_preferences),},
   {"action-menu", NULL, N_("_Actions"), NULL, NULL, NULL},
   {"view-menu", NULL, N_("_View"), NULL, NULL, NULL},
-  {"refresh", GTK_STOCK_REFRESH, N_("Refresh"), NULL, N_("Refresh file list"),
+  {"refresh", "view-refresh", N_("Refresh"), NULL, N_("Refresh file list"),
    G_CALLBACK (action_refresh_directorybrowser),},
   {"help-menu", NULL, N_("_Help"), NULL, NULL, NULL},
-  {"about", GTK_STOCK_ABOUT, N_("_About"), NULL, N_("Display information about Xfburn"),
+  {"about", "gtk-about", N_("_About"), NULL, N_("Display information about Xfburn"),
    G_CALLBACK (action_about),},
   {"blank-disc", "xfburn-blank-cdrw", N_("Blank CD-RW"), NULL, N_("Blank CD-RW"),
    G_CALLBACK (action_blank),},
   {"copy-data", "xfburn-data-copy", N_("Copy Data CD"), NULL, N_("Copy Data CD"),
    G_CALLBACK (action_copy_cd),},
   /*{"copy-audio", "xfburn-audio-copy", N_("Copy Audio CD"), NULL, N_("Copy Audio CD"),}, */
-  {"burn-image", "stock_xfburn", N_("Burn Image"), NULL, N_("Burn Image"),
+/*  {"burn-image", "stock_xfburn", N_("Burn Image"), NULL, N_("Burn Image"),
    G_CALLBACK (action_burn_image),},
 /*  {"copy-dvd", "xfburn-data-copy", N_("Copy DVD"), NULL, N_("Copy DVD"),
    G_CALLBACK (action_copy_dvd),}, */
-  {"burn-dvd", "xfburn-burn-image", N_("Burn DVD Image"), NULL, N_("Burn DVD Image"),
+/*  {"burn-dvd", "xfburn-burn-image", N_("Burn DVD Image"), NULL, N_("Burn DVD Image"),
    G_CALLBACK (action_burn_dvd_image),},
 };
-
-static const GtkToggleActionEntry toggle_action_entries[] = {
+*/
+static const GActionEntry toggle_action_entries[] = {
+  { .name = "show-filebrowser", .state = "false", .change_state = (gActionCallback)action_show_filebrowser },
+  { .name = "show-toolbar", .state = "false", .change_state = (gActionCallback)action_show_toolbar },
+};
+/* static const GtkToggleActionEntry toggle_action_entries[] = {
   {"show-filebrowser", NULL, N_("Show file browser"), NULL, N_("Show/hide the file browser"),
    G_CALLBACK (action_show_filebrowser), TRUE,},
   {"show-toolbar", NULL, N_("Show toolbar"), NULL, N_("Show/hide the toolbar"),
    G_CALLBACK (action_show_toolbar), TRUE,},
-};
+}; */
 
 static const gchar *toolbar_actions[] = {
   "new-data-composition",
@@ -166,38 +196,11 @@ static XfburnMainWindow *instance = NULL;
 /**************************/
 /* XfburnMainWindow class */
 /**************************/
-GType
-xfburn_main_window_get_type (void)
-{
-  static GType main_window_type = 0;
-
-  if (!main_window_type) {
-    static const GTypeInfo main_window_info = {
-      sizeof (XfburnMainWindowClass),
-      NULL,
-      NULL,
-      (GClassInitFunc) xfburn_main_window_class_init,
-      NULL,
-      NULL,
-      sizeof (XfburnMainWindow),
-      0,
-      (GInstanceInitFunc) xfburn_main_window_init,
-      NULL
-    };
-
-    main_window_type = g_type_register_static (GTK_TYPE_WINDOW, "XfburnMainWindow", &main_window_info, 0);
-  }
-
-  return main_window_type;
-}
-
 static void
 xfburn_main_window_class_init (XfburnMainWindowClass * klass)
 {
   GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
-  g_type_class_add_private (klass, sizeof (XfburnMainWindowPrivate));
-
   parent_class = g_type_class_peek_parent (klass);
 
   object_class->finalize = xfburn_main_window_finalize;
@@ -230,26 +233,24 @@ xfburn_main_window_init (XfburnMainWindow * mainwin)
   g_signal_connect (G_OBJECT (mainwin), "delete-event", G_CALLBACK (cb_delete_main_window), priv);
 
   /* create ui manager */
-  priv->action_group = gtk_action_group_new ("xfburn-main-window");
-  gtk_action_group_set_translation_domain (priv->action_group, GETTEXT_PACKAGE);
-  gtk_action_group_add_actions (priv->action_group, action_entries, G_N_ELEMENTS (action_entries),
-                                GTK_WIDGET (mainwin));
-  gtk_action_group_add_toggle_actions (priv->action_group, toggle_action_entries,
-                                       G_N_ELEMENTS (toggle_action_entries), GTK_WIDGET (mainwin));
+  priv->ui_manager = gtk_builder_new ();
+  gtk_builder_set_translation_domain (priv->ui_manager, GETTEXT_PACKAGE);
 
-  priv->ui_manager = gtk_ui_manager_new ();
-  gtk_ui_manager_insert_action_group (priv->ui_manager, priv->action_group, 0);
+  priv->action_map = g_simple_action_group_new();
+
+  g_action_map_add_action_entries (G_ACTION_MAP (priv->action_map), action_entries, G_N_ELEMENTS(action_entries), mainwin);
+  g_action_map_add_action_entries (G_ACTION_MAP (priv->action_map), toggle_action_entries, G_N_ELEMENTS(toggle_action_entries), mainwin);
 
   xfce_resource_push_path (XFCE_RESOURCE_DATA, DATADIR);
   file = xfce_resource_lookup (XFCE_RESOURCE_DATA, "xfburn/xfburn.ui");
 
   if (G_LIKELY (file != NULL)) {
     GError *error = NULL;
-    if (gtk_ui_manager_add_ui_from_file (priv->ui_manager, file, &error) == 0) {
+    if (gtk_builder_add_from_file (priv->ui_manager, file, &error) == 0) {
       g_warning ("Unable to load %s: %s", file, error->message);
       g_error_free (error);
     }
-    gtk_ui_manager_ensure_update (priv->ui_manager);
+//    gtk_ui_manager_ensure_update (priv->ui_manager);
     g_free (file);
   }
   else {
@@ -257,22 +258,25 @@ xfburn_main_window_init (XfburnMainWindow * mainwin)
   }
 
   /* accel group */
-  accel_group = gtk_ui_manager_get_accel_group (priv->ui_manager);
+ /* accel_group = gtk_ui_manager_get_accel_group (priv->ui_manager);
   gtk_window_add_accel_group (GTK_WINDOW (mainwin), accel_group);
-
-  vbox = gtk_vbox_new (FALSE, 0);
+*/
+  vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
   gtk_container_add (GTK_CONTAINER (mainwin), vbox);
   gtk_widget_show (vbox);
 
   /* menubar */
-  priv->menubar = gtk_ui_manager_get_widget (priv->ui_manager, "/main-menu");
+  GMenuModel *menu_model = (GMenuModel*)gtk_builder_get_object (priv->ui_manager, "main-menu");
+  
+  priv->menubar = gtk_menu_bar_new_from_model (menu_model);
   if (G_LIKELY (priv->menubar != NULL)) {
+    gtk_widget_insert_action_group (priv->menubar, "app", G_ACTION_GROUP (priv->action_map));
     gtk_box_pack_start (GTK_BOX (vbox), priv->menubar, FALSE, FALSE, 0);
     gtk_widget_show (priv->menubar);
   }
 
   /* toolbar */
-  file = xfce_resource_lookup (XFCE_RESOURCE_DATA, "xfburn/xfburn-toolbars.ui");
+/*  file = xfce_resource_lookup (XFCE_RESOURCE_DATA, "xfburn/xfburn-toolbars.ui");
 
   if (G_LIKELY (file != NULL)) {
     ExoToolbarsModel *model;
@@ -285,7 +289,7 @@ xfburn_main_window_init (XfburnMainWindow * mainwin)
       gtk_box_pack_start (GTK_BOX (vbox), priv->toolbars, FALSE, FALSE, 0);
       gtk_widget_show (priv->toolbars);
 
-      g_signal_connect (G_OBJECT (priv->toolbars), "customize", G_CALLBACK (cb_edit_toolbars_view), mainwin);
+//      g_signal_connect (G_OBJECT (priv->toolbars), "customize", G_CALLBACK (cb_edit_toolbars_view), mainwin);
     }
     else {
       g_warning ("Unable to load %s: %s", file, error->message);
@@ -297,10 +301,38 @@ xfburn_main_window_init (XfburnMainWindow * mainwin)
   else {
     g_warning ("Unable to locate xfburn/xfburn-toolbars.ui !");
   }
+*/
+  priv->toolbars = gtk_toolbar_new ();
+  gtk_toolbar_set_style(GTK_TOOLBAR (priv->toolbars), GTK_TOOLBAR_BOTH);
+  gtk_widget_insert_action_group (priv->toolbars, "app", G_ACTION_GROUP (priv->action_map));
+
+  xfburn_add_button_to_toolbar (GTK_TOOLBAR (priv->toolbars),
+    "stock_xfburn-new-data-composition", "New data composition", "app.new-data-composition", NULL);
+
+  xfburn_add_button_to_toolbar (GTK_TOOLBAR (priv->toolbars),
+    "stock_xfburn-audio-cd", "New audio composition", "app.new-audio-composition", NULL);
+
+  gtk_toolbar_insert (GTK_TOOLBAR (priv->toolbars), gtk_separator_tool_item_new(), -1);
+
+  xfburn_add_button_to_toolbar (GTK_TOOLBAR (priv->toolbars), 
+    "stock_xfburn-blank-cdrw", "Blank CD-RW", "app.blank-disc", NULL);
+  
+  xfburn_add_button_to_toolbar (GTK_TOOLBAR (priv->toolbars),
+    "stock_xfburn", "Burn Image", "app.burn-image", NULL);
+
+  gtk_toolbar_insert (GTK_TOOLBAR (priv->toolbars), gtk_separator_tool_item_new(), -1);
+
+  xfburn_add_button_to_toolbar (GTK_TOOLBAR (priv->toolbars),
+    "view-refresh", "Refresh", "app.refresh", "Refresh file list");
+
+  gtk_box_pack_start (GTK_BOX (vbox), priv->toolbars, FALSE, FALSE, 5);
+  gtk_toolbar_set_icon_size(GTK_TOOLBAR (priv->toolbars), GTK_ICON_SIZE_SMALL_TOOLBAR);
+  gtk_tool_shell_rebuild_menu(GTK_TOOL_SHELL (priv->toolbars));
+  gtk_widget_show_all (priv->toolbars);
 
   /* vpaned */
-  priv->vpaned = gtk_vpaned_new ();
-  gtk_container_add (GTK_CONTAINER (vbox), priv->vpaned);
+  priv->vpaned = gtk_paned_new (GTK_ORIENTATION_VERTICAL);
+  gtk_box_pack_start (GTK_BOX (vbox), priv->vpaned, TRUE, TRUE, 0);
   gtk_widget_show (priv->vpaned);
 
   /* filebrowser */
@@ -309,18 +341,19 @@ xfburn_main_window_init (XfburnMainWindow * mainwin)
   gtk_widget_show (priv->file_browser);
 
   gtk_paned_set_position (GTK_PANED (priv->file_browser), xfburn_settings_get_int ("hpaned-position", 250));
-  
+
   /* compositions notebook */
   priv->compositions_notebook = xfburn_compositions_notebook_new ();
   gtk_widget_show (priv->compositions_notebook);
   gtk_paned_pack2 (GTK_PANED (priv->vpaned), priv->compositions_notebook, TRUE, FALSE);
-  
+
   gtk_paned_set_position (GTK_PANED (priv->vpaned), xfburn_settings_get_int ("vpaned-position", 200));
 
   xfce_resource_pop_path (XFCE_RESOURCE_DATA);
 }
 
 /* internals */
+/*
 static void
 cb_edit_toolbars_view_done (ExoToolbarsEditorDialog * dialog, ExoToolbarsView * toolbar)
 {
@@ -353,13 +386,14 @@ cb_edit_toolbars_view (ExoToolbarsView * toolbar, gpointer user_data)
 
   g_signal_connect (G_OBJECT (editor_dialog), "destroy", G_CALLBACK (cb_edit_toolbars_view_done), toolbar);
 }
+*/
 
 static gboolean
 cb_delete_main_window (XfburnMainWindow * mainwin, GdkEvent * event, XfburnMainWindowPrivate *priv)
 {
   gint x, y;
 
-  gtk_window_get_size (GTK_WINDOW (mainwin), &x, &y); 
+  gtk_window_get_size (GTK_WINDOW (mainwin), &x, &y);
   xfburn_settings_set_int ("main-window-width", x);
   xfburn_settings_set_int ("main-window-height", y);
 
@@ -372,29 +406,29 @@ cb_delete_main_window (XfburnMainWindow * mainwin, GdkEvent * event, XfburnMainW
 
 /* actions */
 static void
-action_blank (GtkAction * action, XfburnMainWindow * window)
+action_blank (GAction * action, GVariant* param, XfburnMainWindow * window)
 {
   GtkWidget *dialog;
-  
+
   dialog = xfburn_blank_dialog_new ();
   gtk_window_set_transient_for (GTK_WINDOW (dialog), GTK_WINDOW (window));
   gtk_dialog_run (GTK_DIALOG (dialog));
   gtk_widget_destroy (dialog);
 }
 
-static void action_copy_cd (GtkAction *action, XfburnMainWindow *window)
+static void action_copy_cd (GAction *action, GVariant* param, XfburnMainWindow *window)
 {
   /*
   GtkWidget *dialog;
   dialog = xfburn_copy_cd_dialog_new ();
   gtk_window_set_transient_for (GTK_WINDOW (dialog), GTK_WINDOW (window));
-  gtk_dialog_run (GTK_DIALOG (dialog)); 
+  gtk_dialog_run (GTK_DIALOG (dialog));
   gtk_widget_destroy (dialog);
   */
 }
 
 static void
-action_burn_image (GtkAction * action, XfburnMainWindow * window)
+action_burn_image (GAction * action, GVariant* param, XfburnMainWindow * window)
 {
   GtkWidget *dialog;
 
@@ -409,16 +443,16 @@ static void
 action_copy_dvd (GtkAction * action, XfburnMainWindow * window)
 {
   GtkWidget *dialog;
-  
+
   dialog = xfburn_copy_dvd_dialog_new ();
   gtk_window_set_transient_for (GTK_WINDOW (dialog), GTK_WINDOW (window));
-  gtk_dialog_run (GTK_DIALOG (dialog)); 
+  gtk_dialog_run (GTK_DIALOG (dialog));
   gtk_widget_destroy (dialog);
 }
 */
 
 static void
-action_burn_dvd_image (GtkAction * action, XfburnMainWindow * window)
+action_burn_dvd_image (GAction * action, GVariant* param, XfburnMainWindow * window)
 {
 }
 
@@ -427,7 +461,7 @@ static void
 action_load (GtkAction *action, XfburnMainWindow * window)
 {
   //XfburnMainWindowPrivate *priv = XFBURN_MAIN_WINDOW_GET_PRIVATE (window);
-  
+
   //xfburn_data_composition_load_from_file (XFBURN_DATA_COMPOSITION (priv->data_composition), "/tmp/test.xml");
 }
 
@@ -435,7 +469,7 @@ static void
 action_save (GtkAction *action, XfburnMainWindow * window)
 {
   XfburnMainWindowPrivate *priv = XFBURN_MAIN_WINDOW_GET_PRIVATE (window);
-  
+
   xfburn_compositions_notebook_save_composition (XFBURN_COMPOSITIONS_NOTEBOOK (priv->compositions_notebook));
 }
 
@@ -443,47 +477,48 @@ static void
 action_save_as (GtkAction *action, XfburnMainWindow * window)
 {
   //XfburnMainWindowPrivate *priv = XFBURN_MAIN_WINDOW_GET_PRIVATE (window);
-  
+
 }
 */
 
 static void
-action_close (GtkAction *action, XfburnMainWindow * window)
+action_close (GAction *action, GVariant* param, XfburnMainWindow * window)
 {
   XfburnMainWindowPrivate *priv = XFBURN_MAIN_WINDOW_GET_PRIVATE (window);
-  
+
   xfburn_compositions_notebook_close_composition (XFBURN_COMPOSITIONS_NOTEBOOK (priv->compositions_notebook));
 }
 
 static void
-action_new_data_composition (GtkAction *action, XfburnMainWindow * window)
+action_new_data_composition (GAction *action, GVariant* param, XfburnMainWindow * window)
 {
   xfburn_main_window_add_data_composition_with_files (window, 0, NULL);
 }
 
 static void
-action_new_audio_composition (GtkAction *action, XfburnMainWindow * window)
+action_new_audio_composition (GAction *action, GVariant* param, XfburnMainWindow * window)
 {
   //XfburnMainWindowPrivate *priv = XFBURN_MAIN_WINDOW_GET_PRIVATE (window);
- 
+
   xfburn_main_window_add_audio_composition_with_files (window, 0, NULL);
 }
 
 static void
-action_quit (GtkAction * action, XfburnMainWindow * window)
+action_quit (GAction * action, GVariant* param, XfburnMainWindow * window)
 {
-  // if (xfce_confirm (_("Are sure you want to quit?"), GTK_STOCK_QUIT, _("_Quit")))
+  // if (xfce_confirm (_("Are sure you want to quit?"), "application-exit", _("_Quit")))
   gtk_main_quit ();
 }
 
 static void
-action_about (GtkAction * action, XfburnMainWindow * window)
+action_about (GAction * action, GVariant* param, XfburnMainWindow * window)
 {
   gint x, y;
   GdkPixbuf *icon = NULL;
   const gchar *auth[] = { "David Mohr david@mcbf.net Author/Maintainer",
-	  		  "Mario Đanić mario@libburnia-project.org Author/Maintainer",
+			  "Mario Đanić mario@libburnia-project.org Author/Maintainer",
 			  "Jean-François Wauthy pollux@xfce.org Retired author/maintainer",
+			  "Rene Kjellerup rk.katana.steel@gmail.com Author/GTK+3",
 			  NULL };
   const gchar *translators =
     "Mohamed Magdy mohamed.m.k@gmail.com ar\n"
@@ -524,7 +559,7 @@ action_about (GtkAction * action, XfburnMainWindow * window)
   if (!icon)
     icon = gtk_icon_theme_load_icon ( gtk_icon_theme_get_default(), "media-cdrom", x, GTK_ICON_LOOKUP_GENERIC_FALLBACK, NULL);
   if (!icon)
-    icon = gtk_icon_theme_load_icon ( gtk_icon_theme_get_default(), GTK_STOCK_CDROM, x, GTK_ICON_LOOKUP_GENERIC_FALLBACK, NULL);
+    icon = gtk_icon_theme_load_icon ( gtk_icon_theme_get_default(), "media-optical", x, GTK_ICON_LOOKUP_GENERIC_FALLBACK, NULL);
 
 #if !GTK_CHECK_VERSION (2, 18, 0)
   gtk_about_dialog_set_email_hook (exo_gtk_url_about_dialog_hook, NULL, NULL);
@@ -536,9 +571,9 @@ action_about (GtkAction * action, XfburnMainWindow * window)
 		  "license", xfce_get_license_text (XFCE_LICENSE_TEXT_GPL),
 		  "version", VERSION,
 		  "comments", _("Another cd burning GUI"),
-		  "website", "http://www.xfce.org/projects/xfburn",
+		  "website", "https://goodies.xfce.org/projects/applications/xfburn",
 		  "copyright", "2005-2008 David Mohr, Mario Đanić, Jean-François Wauthy",
-		  "authors", auth, 
+		  "authors", auth,
 		  "translator-credits", translators,
 		  NULL);
 
@@ -547,34 +582,38 @@ action_about (GtkAction * action, XfburnMainWindow * window)
 }
 
 static void
-action_preferences (GtkAction * action, XfburnMainWindow * window)
+action_preferences (GAction * action, GVariant* param, XfburnMainWindow * window)
 {
   GtkWidget *dialog;
 
   dialog = xfburn_preferences_dialog_new ();
   gtk_window_set_transient_for (GTK_WINDOW (dialog), GTK_WINDOW (window));
-  
+
   gtk_dialog_run (GTK_DIALOG (dialog));
   gtk_widget_destroy (dialog);
 }
 
 static void
-action_refresh_directorybrowser (GtkAction * action, XfburnMainWindow * window)
+action_refresh_directorybrowser (GAction * action, GVariant* param, XfburnMainWindow * window)
 {
   XfburnMainWindowPrivate *priv = XFBURN_MAIN_WINDOW_GET_PRIVATE (window);
-  
+
   xfburn_file_browser_refresh (XFBURN_FILE_BROWSER (priv->file_browser));
 }
 
 static void
-action_show_filebrowser (GtkToggleAction * action, XfburnMainWindow * window)
+action_show_filebrowser (GSimpleAction * action, GVariant* value, XfburnMainWindow * window)
 {
+  if(g_variant_is_of_type (value, G_VARIANT_TYPE_BOOLEAN))
+    g_simple_action_set_state (action, value);
+
   XfburnMainWindowPrivate *priv = XFBURN_MAIN_WINDOW_GET_PRIVATE (window);
-  
-  xfburn_settings_set_boolean ("show-filebrowser", gtk_toggle_action_get_active (action));
-  
-  if (gtk_toggle_action_get_active (action)) {
-    gtk_widget_show (priv->file_browser);  
+  GAction *file = g_action_map_lookup_action(G_ACTION_MAP(priv->action_map), "show-filebrowser");
+  gboolean toggle = g_variant_get_boolean  (g_action_get_state (file));
+  xfburn_settings_set_boolean ("show-filebrowser", toggle);
+
+  if ( toggle ) {
+    gtk_widget_show (priv->file_browser);
   }
   else {
     gtk_widget_hide (priv->file_browser);
@@ -582,13 +621,17 @@ action_show_filebrowser (GtkToggleAction * action, XfburnMainWindow * window)
 }
 
 static void
-action_show_toolbar (GtkToggleAction * action, XfburnMainWindow * window)
+action_show_toolbar (GSimpleAction * action, GVariant* value, XfburnMainWindow * window)
 {
+  if(g_variant_is_of_type (value, G_VARIANT_TYPE_BOOLEAN))
+    g_simple_action_set_state (action, value);
   XfburnMainWindowPrivate *priv = XFBURN_MAIN_WINDOW_GET_PRIVATE (window);
-  
-  xfburn_settings_set_boolean ("show-toolbar", gtk_toggle_action_get_active (action));
-  
-  if (gtk_toggle_action_get_active (action)) {
+  GAction *tool = g_action_map_lookup_action(G_ACTION_MAP(priv->action_map), "show-toolbar");
+  gboolean toggle = g_variant_get_boolean (g_action_get_state (tool));
+
+  xfburn_settings_set_boolean ("show-toolbar", toggle);
+
+  if ( toggle ) {
     gtk_widget_show (priv->toolbars);
   }
   else {
@@ -596,6 +639,7 @@ action_show_toolbar (GtkToggleAction * action, XfburnMainWindow * window)
   }
 }
 
+
 /******************/
 /* public methods */
 /******************/
@@ -608,24 +652,25 @@ xfburn_main_window_new (void)
     g_error ("An instance of XfburnMainWindow has already been created");
     return NULL;
   }
-  
-  obj = g_object_new (xfburn_main_window_get_type (), NULL);
-  
+
+  obj = gtk_widget_new (xfburn_main_window_get_type (), NULL);
+
   if (obj) {
     XfburnMainWindow *win;
     XfburnMainWindowPrivate *priv;
-    GtkAction *action;
+    GAction *action;
+    GActionMap *action_map;
     GList *device = NULL;
     XfburnDeviceList *devlist;
-    
+
     instance = win = XFBURN_MAIN_WINDOW (obj);
     priv = XFBURN_MAIN_WINDOW_GET_PRIVATE (win);
-
+    action_map = G_ACTION_MAP (priv->action_map);
     /* load settings */
-    action = gtk_action_group_get_action (priv->action_group, "show-filebrowser");
-    gtk_toggle_action_set_active (GTK_TOGGLE_ACTION (action), xfburn_settings_get_boolean ("show-filebrowser", FALSE));
-    action = gtk_action_group_get_action (priv->action_group, "show-toolbar");
-    gtk_toggle_action_set_active (GTK_TOGGLE_ACTION (action), xfburn_settings_get_boolean ("show-toolbar", FALSE));
+    action = g_action_map_lookup_action (action_map, "show-filebrowser");
+    g_action_change_state (action, g_variant_new_boolean (xfburn_settings_get_boolean ("show-filebrowser", FALSE)));
+    action = g_action_map_lookup_action (action_map, "show-toolbar");
+    g_action_change_state (action, g_variant_new_boolean (xfburn_settings_get_boolean ("show-toolbar", FALSE)));
    /* action = gtk_action_group_get_action (priv->action_group, "save-composition");
     gtk_action_set_sensitive (GTK_ACTION (action), FALSE);*/
 
@@ -643,28 +688,28 @@ xfburn_main_window_new (void)
       g_object_get (G_OBJECT (device_info), "cdr", &cdr, "cdrw", &cdrw, NULL);
 
       if (cdr)
-	priv->support_cdr = TRUE;
+        priv->support_cdr = TRUE;
       if (cdrw)
-	priv->support_cdrw = TRUE;
+        priv->support_cdrw = TRUE;
 
       device = g_list_next (device);
     }
 
     if (!priv->support_cdr) {
-      action = gtk_action_group_get_action (priv->action_group, "copy-data");
-      gtk_action_set_sensitive (action, FALSE);
-      action = gtk_action_group_get_action (priv->action_group, "copy-audio");
-      gtk_action_set_sensitive (action, FALSE);
-      action = gtk_action_group_get_action (priv->action_group, "burn-image");
-      gtk_action_set_sensitive (action, FALSE);
+      action = g_action_map_lookup_action (action_map, "copy-data");
+      g_simple_action_set_enabled (G_SIMPLE_ACTION (action), FALSE);
+      action = g_action_map_lookup_action (action_map, "copy-audio");
+      g_simple_action_set_enabled (G_SIMPLE_ACTION (action), FALSE);
+      action = g_action_map_lookup_action (action_map, "burn-image");
+      g_simple_action_set_enabled (G_SIMPLE_ACTION (action), FALSE);
     }
     if (!priv->support_cdrw) {
-      action = gtk_action_group_get_action (priv->action_group, "blank-disc");
-      gtk_action_set_sensitive (action, FALSE);
+      action = g_action_map_lookup_action (action_map, "blank-disc");
+      g_simple_action_set_enabled (G_SIMPLE_ACTION (action), FALSE);
     }
 
     /* show welcome tab */
-    xfburn_compositions_notebook_add_welcome_tab (XFBURN_COMPOSITIONS_NOTEBOOK (priv->compositions_notebook), priv->action_group);
+    xfburn_compositions_notebook_add_welcome_tab (XFBURN_COMPOSITIONS_NOTEBOOK (priv->compositions_notebook), action_map);
   }
 
   return obj;
@@ -678,43 +723,43 @@ xfburn_main_window_get_instance (void)
 
   return instance;
 }
-
+/*
 GtkUIManager *
 xfburn_main_window_get_ui_manager (XfburnMainWindow *window)
 {
   XfburnMainWindowPrivate *priv = XFBURN_MAIN_WINDOW_GET_PRIVATE (window);
-  
+
   return priv->ui_manager;
 }
-
+*/
 XfburnFileBrowser *
 xfburn_main_window_get_file_browser (XfburnMainWindow *window)
 {
   XfburnMainWindowPrivate *priv = XFBURN_MAIN_WINDOW_GET_PRIVATE (window);
-  
+
   return XFBURN_FILE_BROWSER (priv->file_browser);
 }
 
-void 
+void
 xfburn_main_window_add_data_composition_with_files (XfburnMainWindow *window, int filec, char **filenames)
 {
   XfburnMainWindowPrivate *priv = XFBURN_MAIN_WINDOW_GET_PRIVATE (window);
   XfburnComposition *comp;
   GSList * filelist;
- 
+
   comp = xfburn_compositions_notebook_add_composition (XFBURN_COMPOSITIONS_NOTEBOOK (priv->compositions_notebook), XFBURN_DATA_COMPOSITION);
 
   filelist = xfburn_make_abosulet_file_list (filec, filenames);
   xfburn_data_composition_add_files (XFBURN_DATA_COMPOSITION (comp), filelist);
 }
 
-void 
+void
 xfburn_main_window_add_audio_composition_with_files (XfburnMainWindow *window, int filec, char **filenames)
 {
   XfburnMainWindowPrivate *priv = XFBURN_MAIN_WINDOW_GET_PRIVATE (window);
   XfburnComposition *comp;
   GSList * filelist;
- 
+
   comp = xfburn_compositions_notebook_add_composition (XFBURN_COMPOSITIONS_NOTEBOOK (priv->compositions_notebook), XFBURN_AUDIO_COMPOSITION);
   filelist = xfburn_make_abosulet_file_list (filec, filenames);
   xfburn_audio_composition_add_files (XFBURN_AUDIO_COMPOSITION (comp), filelist);
