@@ -30,7 +30,7 @@
 
 #define FIFO_MAX_SIZE     16384.0  /* in kb, as float */
 
-#define XFBURN_PREFERENCES_DIALOG_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE ((obj), XFBURN_TYPE_PREFERENCES_DIALOG, XfburnPreferencesDialogPrivate))
+#define XFBURN_PREFERENCES_DIALOG_GET_PRIVATE(obj) (xfburn_preferences_dialog_get_instance_private (XFBURN_PREFERENCES_DIALOG (obj)))
 
 typedef struct
 {
@@ -51,9 +51,6 @@ typedef struct
 } XfburnPreferencesDialogPrivate;
 
 /* prototypes */
-static void xfburn_preferences_dialog_class_init (XfburnPreferencesDialogClass * klass);
-static void xfburn_preferences_dialog_init (XfburnPreferencesDialog * sp);
-
 static void refresh_devices_list (XfburnPreferencesDialog * dialog);
 static void scan_button_clicked_cb (GtkWidget * button, gpointer user_data);
 static void xfburn_preferences_dialog_response_cb (XfburnPreferencesDialog * dialog, guint response_id, XfburnPreferencesDialogPrivate * priv);
@@ -89,43 +86,18 @@ typedef struct
 /*********************************/
 static XfceTitledDialogClass *parent_class = NULL;
 
-GType
-xfburn_preferences_dialog_get_type (void)
-{
-  static GType type = 0;
-
-  if (type == 0) {
-    static const GTypeInfo our_info = {
-      sizeof (XfburnPreferencesDialogClass),
-      NULL,
-      NULL,
-      (GClassInitFunc) xfburn_preferences_dialog_class_init,
-      NULL,
-      NULL,
-      sizeof (XfburnPreferencesDialog),
-      0,
-      (GInstanceInitFunc) xfburn_preferences_dialog_init,
-      NULL
-    };
-
-    type = g_type_register_static (XFCE_TYPE_TITLED_DIALOG, "XfburnPreferencesDialog", &our_info, 0);
-  }
-
-  return type;
-}
+G_DEFINE_TYPE_WITH_PRIVATE(XfburnPreferencesDialog, xfburn_preferences_dialog, XFCE_TYPE_TITLED_DIALOG);
 
 static void
 xfburn_preferences_dialog_class_init (XfburnPreferencesDialogClass * klass)
 {
-  g_type_class_add_private (klass, sizeof (XfburnPreferencesDialogPrivate));
-  
   parent_class = g_type_class_peek_parent (klass);
 }
 
 static void
 xfburn_preferences_dialog_init (XfburnPreferencesDialog * obj)
 {
-  GtkBox *box = GTK_BOX (GTK_DIALOG (obj)->vbox);
+  GtkBox *box = GTK_BOX (gtk_dialog_get_content_area(GTK_DIALOG (obj)));
   XfburnPreferencesDialogPrivate *priv = XFBURN_PREFERENCES_DIALOG_GET_PRIVATE (obj);
   
   GtkWidget *vbox, *vbox2, *vbox3, *hbox;
@@ -145,13 +117,12 @@ xfburn_preferences_dialog_init (XfburnPreferencesDialog * obj)
   xfce_titled_dialog_set_subtitle (XFCE_TITLED_DIALOG (obj), _("Tune how Xfburn behaves"));
   gtk_window_set_default_size (GTK_WINDOW (obj), 775, 400);
   gtk_window_set_destroy_with_parent (GTK_WINDOW (obj), TRUE);
-  gtk_window_set_icon_name (GTK_WINDOW (obj), GTK_STOCK_PREFERENCES);
-  gtk_dialog_set_has_separator (GTK_DIALOG (obj), FALSE);
+  gtk_window_set_icon_name (GTK_WINDOW (obj), "preferences-system");
   
-  hbox = gtk_hbox_new (FALSE, 0);
+  hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
   gtk_box_pack_start (box, hbox, TRUE, TRUE, 0);
   gtk_widget_show (hbox);
-
+/*  // because exo icon bar isn't available disabling the side panel scrolled window
   scrolled_window = gtk_scrolled_window_new (NULL, NULL);
   g_object_set (G_OBJECT (scrolled_window),
                 "hscrollbar-policy", GTK_POLICY_NEVER,
@@ -160,32 +131,32 @@ xfburn_preferences_dialog_init (XfburnPreferencesDialog * obj)
                 NULL);
   gtk_box_pack_start (GTK_BOX (hbox), scrolled_window, FALSE, FALSE, 0);
   gtk_widget_show (scrolled_window);
-
+*/
   /* icon bar */
   icon_store = gtk_list_store_new (SETTINGS_LIST_N_COLUMNS, GDK_TYPE_PIXBUF, G_TYPE_STRING, G_TYPE_INT);
-  priv->icon_bar = exo_icon_bar_new_with_model (GTK_TREE_MODEL (icon_store));
-  exo_icon_bar_set_pixbuf_column (EXO_ICON_BAR (priv->icon_bar), SETTINGS_LIST_PIXBUF_COLUMN);
-  exo_icon_bar_set_text_column (EXO_ICON_BAR (priv->icon_bar), SETTINGS_LIST_TEXT_COLUMN);
-  gtk_container_add (GTK_CONTAINER (scrolled_window), priv->icon_bar);
-  gtk_widget_show (priv->icon_bar);
-  
+  // priv->icon_bar = exo_icon_view_new_with_model (GTK_TREE_MODEL (icon_store));
+  // g_object_set_property (G_OBJECT (priv->icon_bar), "pixbuf-column", &pb_col);
+  // g_object_set_property (G_OBJECT (priv->icon_bar), "text-column", &tx_col);
+  // gtk_container_add (GTK_CONTAINER (scrolled_window), priv->icon_bar);
+  // gtk_widget_show (priv->icon_bar);
+
   /* notebook */
   priv->notebook = gtk_notebook_new ();
   gtk_container_set_border_width (GTK_CONTAINER (priv->notebook), BORDER);
   g_object_set (G_OBJECT (priv->notebook),
                 "show-border", FALSE,
-                "show-tabs", FALSE,
+                "show-tabs", TRUE, // enabling the notebook tabs
                 NULL);
   gtk_box_pack_start (GTK_BOX (hbox), priv->notebook, TRUE, TRUE, BORDER);
   gtk_widget_show (priv->notebook);
 
   /* general tab */
-  vbox = gtk_vbox_new (FALSE, 0);
+  vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
   gtk_container_set_border_width (GTK_CONTAINER (vbox), BORDER);
   idx = gtk_notebook_append_page (GTK_NOTEBOOK (priv->notebook), vbox, NULL);
   gtk_widget_show (vbox);
 
-  vbox2 = gtk_vbox_new (FALSE, 0);
+  vbox2 = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
   gtk_widget_show (vbox2);
 
   frame = xfce_gtk_frame_box_new_with_content (_("Temporary directory"), vbox2);
@@ -200,7 +171,7 @@ xfburn_preferences_dialog_init (XfburnPreferencesDialog * obj)
   gtk_box_pack_start (GTK_BOX (vbox2), priv->check_clean_tmpdir, FALSE, FALSE, BORDER);
   gtk_widget_show (priv->check_clean_tmpdir);
 
-  vbox2 = gtk_vbox_new (FALSE, 0);
+  vbox2 = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
   gtk_widget_show (vbox2);
 
   frame = xfce_gtk_frame_box_new_with_content (_("File browser"), vbox2);
@@ -216,10 +187,9 @@ xfburn_preferences_dialog_init (XfburnPreferencesDialog * obj)
   gtk_box_pack_start (GTK_BOX (vbox2), priv->check_show_human_readable, FALSE, FALSE, BORDER);
   gtk_widget_show (priv->check_show_human_readable);
 
-  icon = gtk_widget_render_icon (GTK_WIDGET (priv->icon_bar),
-                                 GTK_STOCK_PROPERTIES,
-                                 GTK_ICON_SIZE_DIALOG,
-                                 NULL);
+  gtk_icon_size_lookup (GTK_ICON_SIZE_DIALOG, &x, &y);
+  icon = gtk_icon_theme_load_icon ( gtk_icon_theme_get_default(), "document-properties", x, GTK_ICON_LOOKUP_GENERIC_FALLBACK, NULL);
+
   gtk_list_store_append (icon_store, &iter);
   gtk_list_store_set (icon_store, &iter,
                       SETTINGS_LIST_PIXBUF_COLUMN, icon,
@@ -229,18 +199,22 @@ xfburn_preferences_dialog_init (XfburnPreferencesDialog * obj)
   g_object_unref (G_OBJECT (icon));
   
   /* devices tab */
-  vbox = gtk_vbox_new (FALSE, 0);
+  vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
   gtk_container_set_border_width (GTK_CONTAINER (vbox), BORDER);
   idx = gtk_notebook_append_page (GTK_NOTEBOOK (priv->notebook), vbox, NULL);
   gtk_widget_show (vbox);
 
+  label = gtk_label_new (_("General"));
+  gtk_widget_show (label);
+  gtk_notebook_set_tab_label (GTK_NOTEBOOK (priv->notebook),
+                              gtk_notebook_get_nth_page (GTK_NOTEBOOK (priv->notebook), 0), label);
   label = gtk_label_new (_("Devices"));
   gtk_widget_show (label);
   gtk_notebook_set_tab_label (GTK_NOTEBOOK (priv->notebook),
                               gtk_notebook_get_nth_page (GTK_NOTEBOOK (priv->notebook), 1), label);
   gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_LEFT);
 
-  vbox2 = gtk_vbox_new (FALSE, 0);
+  vbox2 = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
   gtk_widget_show (vbox2);
 
   frame = xfce_gtk_frame_box_new_with_content (_("Detected devices"), vbox2);
@@ -258,7 +232,7 @@ xfburn_preferences_dialog_init (XfburnPreferencesDialog * obj)
                               G_TYPE_BOOLEAN);
   priv->treeview_devices = gtk_tree_view_new_with_model (GTK_TREE_MODEL (store));
   gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE (store), DEVICE_LIST_COLUMN_NAME, GTK_SORT_ASCENDING);
-  gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (priv->treeview_devices), TRUE);
+  // gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (priv->treeview_devices), TRUE);
   gtk_widget_show (priv->treeview_devices);
   gtk_container_add (GTK_CONTAINER (scrolled_window), priv->treeview_devices);
   g_object_unref (store);
@@ -295,11 +269,11 @@ xfburn_preferences_dialog_init (XfburnPreferencesDialog * obj)
                                                gtk_cell_renderer_toggle_new (), "active", DEVICE_LIST_COLUMN_BD,
                                                NULL);
 
-  hbox = gtk_hbox_new (FALSE, 0);
+  hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
   gtk_box_pack_start (GTK_BOX (vbox2), hbox, FALSE, FALSE, BORDER);
   gtk_widget_show (hbox);
 
-  priv->button_scan = xfce_gtk_button_new_mixed (GTK_STOCK_CDROM, _("Sc_an for devices"));
+  priv->button_scan = xfce_gtk_button_new_mixed ("media-optical", _("Sc_an for devices"));
   gtk_box_pack_end (GTK_BOX (hbox), priv->button_scan, FALSE, FALSE, BORDER);
   g_signal_connect (G_OBJECT (priv->button_scan), "clicked", G_CALLBACK (scan_button_clicked_cb), obj);
   gtk_widget_show (priv->button_scan);
@@ -309,7 +283,7 @@ xfburn_preferences_dialog_init (XfburnPreferencesDialog * obj)
   if (!icon)
     icon = gtk_icon_theme_load_icon ( gtk_icon_theme_get_default(), "media-cdrom", x, GTK_ICON_LOOKUP_GENERIC_FALLBACK, NULL);
   if (!icon)
-    icon = gtk_icon_theme_load_icon ( gtk_icon_theme_get_default(), GTK_STOCK_CDROM, x, GTK_ICON_LOOKUP_GENERIC_FALLBACK, NULL);
+    icon = gtk_icon_theme_load_icon ( gtk_icon_theme_get_default(), "media-optical", x, GTK_ICON_LOOKUP_GENERIC_FALLBACK, NULL);
 
   
   gtk_list_store_append (icon_store, &iter);
@@ -321,7 +295,7 @@ xfburn_preferences_dialog_init (XfburnPreferencesDialog * obj)
   if (icon)
     g_object_unref (G_OBJECT (icon));
   
-  exo_mutual_binding_new (G_OBJECT (priv->notebook), "page", G_OBJECT (priv->icon_bar), "active");
+//  exo_mutual_binding_new (G_OBJECT (priv->notebook), "page", G_OBJECT (priv->icon_bar), "active");
 
 
   /* below the device list */
@@ -332,14 +306,14 @@ xfburn_preferences_dialog_init (XfburnPreferencesDialog * obj)
 #endif
 
   /* fifo */
-  vbox3 = gtk_vbox_new (FALSE, 0);
+  vbox3 = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
   gtk_widget_show (vbox3);
 
   frame = xfce_gtk_frame_box_new_with_content (_("FIFO buffer size (in kb)"), vbox3);
   gtk_box_pack_start (GTK_BOX (vbox), frame, TRUE, TRUE, BORDER);
   gtk_widget_show (frame);
 
-  priv->scale_fifo = gtk_hscale_new_with_range (0.0, FIFO_MAX_SIZE, 32.0);
+  priv->scale_fifo = gtk_scale_new_with_range (GTK_ORIENTATION_HORIZONTAL, 0.0, FIFO_MAX_SIZE, 32.0);
   gtk_scale_set_value_pos (GTK_SCALE (priv->scale_fifo), GTK_POS_LEFT);
   gtk_range_set_value (GTK_RANGE (priv->scale_fifo), 0);
   gtk_box_pack_start (GTK_BOX (vbox3), priv->scale_fifo, FALSE, FALSE, BORDER/2);
@@ -347,10 +321,23 @@ xfburn_preferences_dialog_init (XfburnPreferencesDialog * obj)
 
   
   /* action buttons */
-  button_close = gtk_button_new_from_stock ("gtk-close");
+  button_close = gtk_button_new ();
+  hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL,0);
+
+  label = gtk_image_new_from_icon_name ("gtk-close", GTK_ICON_SIZE_BUTTON);
+  gtk_widget_show (label);
+  gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
+
+  label = gtk_label_new("close");
+  gtk_widget_show (label);
+  gtk_box_pack_start (GTK_BOX (hbox), label, TRUE, TRUE, 0);
+  gtk_widget_show (hbox);
+
+  gtk_container_add (GTK_CONTAINER(button_close), hbox);
   gtk_widget_show (button_close);
+
   gtk_dialog_add_action_widget (GTK_DIALOG (obj), button_close, GTK_RESPONSE_CLOSE);
-  GTK_WIDGET_SET_FLAGS (button_close, GTK_CAN_DEFAULT);
+  gtk_widget_set_can_default (button_close, TRUE);
   gtk_widget_grab_focus (button_close);
   gtk_widget_grab_default (button_close);
 
