@@ -44,8 +44,6 @@
 
 /** Prototypes **/
 /* class initialization */
-static void xfburn_transcoder_basic_class_init (XfburnTranscoderBasicClass * klass);
-static void xfburn_transcoder_basic_init (XfburnTranscoderBasic * obj);
 static void xfburn_transcoder_basic_finalize (GObject * object);
 static void transcoder_interface_init (XfburnTranscoderInterface *iface, gpointer iface_data);
 
@@ -62,16 +60,10 @@ static gboolean valid_wav_headers (guchar header[44]);
 static struct burn_track * create_burn_track (XfburnTranscoder *trans, XfburnAudioTrack *atrack, GError **error);
 static gboolean needs_swap (char header[44]);
 
-#define XFBURN_TRANSCODER_BASIC_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE ((obj), XFBURN_TYPE_TRANSCODER_BASIC, XfburnTranscoderBasicPrivate))
-
 enum {
   LAST_SIGNAL,
 }; 
 
-typedef struct {
-  gboolean dummy;
-} XfburnTranscoderBasicPrivate;
-
 /* globals */
 
 static const gchar *errormsg_libburn_setup = "An error occurred while setting the burning backend up";
@@ -82,45 +74,19 @@ static const gchar *errormsg_libburn_setup = "An error occurred while setting th
 static GObject *parent_class = NULL;
 //static guint signals[LAST_SIGNAL];
 
-GType
-xfburn_transcoder_basic_get_type (void)
-{
-  static GType type = 0;
-
-  if (type == 0) {
-    static const GTypeInfo our_info = {
-      sizeof (XfburnTranscoderBasicClass),
-      NULL,
-      NULL,
-      (GClassInitFunc) xfburn_transcoder_basic_class_init,
-      NULL,
-      NULL,
-      sizeof (XfburnTranscoderBasic),
-      0,
-      (GInstanceInitFunc) xfburn_transcoder_basic_init,
-      NULL
-    };
-    static const GInterfaceInfo trans_info = {
-      (GInterfaceInitFunc) transcoder_interface_init,
-      NULL,
-      NULL
-    };
-
-    type = g_type_register_static (G_TYPE_OBJECT, "XfburnTranscoderBasic", &our_info, 0);
-
-    g_type_add_interface_static (type, XFBURN_TYPE_TRANSCODER, &trans_info);
-  }
-
-  return type;
-}
+G_DEFINE_TYPE_EXTENDED(
+  XfburnTranscoderBasic,
+  xfburn_transcoder_basic,
+  G_TYPE_OBJECT,
+  0,
+  G_IMPLEMENT_INTERFACE(XFBURN_TYPE_TRANSCODER, transcoder_interface_init)
+);
 
 static void
 xfburn_transcoder_basic_class_init (XfburnTranscoderBasicClass * klass)
 {
   GObjectClass *object_class = G_OBJECT_CLASS (klass);
-  
-  g_type_class_add_private (klass, sizeof (XfburnTranscoderBasicPrivate));
-  
+    
   parent_class = g_type_class_peek_parent (klass);
 
   object_class->finalize = xfburn_transcoder_basic_finalize;
@@ -136,14 +102,11 @@ xfburn_transcoder_basic_class_init (XfburnTranscoderBasicClass * klass)
 static void
 xfburn_transcoder_basic_init (XfburnTranscoderBasic * obj)
 {
-  //XfburnTranscoderBasicPrivate *priv = XFBURN_TRANSCODER_BASIC_GET_PRIVATE (obj);
 }
 
 static void
 xfburn_transcoder_basic_finalize (GObject * object)
 {
-  //XfburnTranscoderBasicPrivate *priv = XFBURN_TRANSCODER_BASIC_GET_PRIVATE (object);
-
   G_OBJECT_CLASS (parent_class)->finalize (object);
 }
 
@@ -229,6 +192,7 @@ static gboolean
 is_valid_wav (const gchar *path)
 {
   int fd;
+  int hread;
   guchar header[44];
   gboolean ret;
 
@@ -239,9 +203,11 @@ is_valid_wav (const gchar *path)
     return FALSE;
   }
 
-  read (fd, header, 44);
-
-  ret = valid_wav_headers (header);
+  ret = FALSE;
+  hread = read (fd, header, 44);
+  if (hread == 44) {
+    ret = valid_wav_headers (header);
+  }
 
   close (fd);
 
@@ -305,12 +271,8 @@ valid_wav_headers (guchar header[44])
 static struct burn_track *
 create_burn_track (XfburnTranscoder *trans, XfburnAudioTrack *atrack, GError **error)
 {
-  /*
-  XfburnTranscoderBasic *basic = XFBURN_TRANSCODER_BASIC (trans);
-  XfburnTranscoderBasicPrivate *priv= XFBURN_TRANSCODER_BASIC_GET_PRIVATE (basic);
-  */
-  
   char header[44];
+  int thead=0;
   struct burn_track *track;
 
   atrack->fd = open (atrack->inputfile, 0);
@@ -322,7 +284,15 @@ create_burn_track (XfburnTranscoder *trans, XfburnAudioTrack *atrack, GError **e
 
   /* advance the fd so that libburn skips the header,
    * also allows us to check for byte swapping */
-  read (atrack->fd, header, 44);
+  thead = read (atrack->fd, header, 44);
+  if( thead < 44 ) {
+    g_warning ("Could not read header from %s!", atrack->inputfile);
+    g_set_error (error, XFBURN_ERROR, XFBURN_ERROR_BURN_SOURCE,
+		 "%s",
+                 _(errormsg_libburn_setup));
+    return NULL;
+  }
+
 
   atrack->src = burn_fd_source_new (atrack->fd, -1 , 0);
   if (atrack->src == NULL) {
