@@ -64,8 +64,6 @@
 
 /** Prototypes **/
 /* class initialization */
-static void xfburn_transcoder_gst_class_init (XfburnTranscoderGstClass * klass);
-static void xfburn_transcoder_gst_init (XfburnTranscoderGst * obj);
 static void xfburn_transcoder_gst_finalize (GObject * object);
 static void transcoder_interface_init (XfburnTranscoderInterface *iface, gpointer iface_data);
 
@@ -93,7 +91,7 @@ static void on_pad_added (GstElement *element, GstPad *pad, gpointer data);
 static void cb_handoff (GstElement *element, GstBuffer *buffer, gpointer data);
 #endif
 
-#define XFBURN_TRANSCODER_GST_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE ((obj), XFBURN_TYPE_TRANSCODER_GST, XfburnTranscoderGstPrivate))
+#define XFBURN_TRANSCODER_GST_GET_PRIVATE(obj) (xfburn_transcoder_gst_get_instance_private ( XFBURN_TRANSCODER_GST (obj)))
 
 enum {
   LAST_SIGNAL,
@@ -157,45 +155,20 @@ static const gchar *errormsg_missing_plugin = "%s is missing.\n"
 static GObject *parent_class = NULL;
 //static guint signals[LAST_SIGNAL];
 
-GType
-xfburn_transcoder_gst_get_type (void)
-{
-  static GType type = 0;
-
-  if (type == 0) {
-    static const GTypeInfo our_info = {
-      sizeof (XfburnTranscoderGstClass),
-      NULL,
-      NULL,
-      (GClassInitFunc) xfburn_transcoder_gst_class_init,
-      NULL,
-      NULL,
-      sizeof (XfburnTranscoderGst),
-      0,
-      (GInstanceInitFunc) xfburn_transcoder_gst_init,
-      NULL
-    };
-    static const GInterfaceInfo trans_info = {
-      (GInterfaceInitFunc) transcoder_interface_init,
-      NULL,
-      NULL
-    };
-
-    type = g_type_register_static (G_TYPE_OBJECT, "XfburnTranscoderGst", &our_info, 0);
-
-    g_type_add_interface_static (type, XFBURN_TYPE_TRANSCODER, &trans_info);
-  }
-
-  return type;
-}
+G_DEFINE_TYPE_EXTENDED(
+  XfburnTranscoderGst,
+  xfburn_transcoder_gst,
+  G_TYPE_OBJECT,
+  0,
+  G_ADD_PRIVATE(XfburnTranscoderGst)
+  G_IMPLEMENT_INTERFACE(XFBURN_TYPE_TRANSCODER, transcoder_interface_init)
+);
 
 static void
 xfburn_transcoder_gst_class_init (XfburnTranscoderGstClass * klass)
 {
   GObjectClass *object_class = G_OBJECT_CLASS (klass);
   
-  g_type_class_add_private (klass, sizeof (XfburnTranscoderGstPrivate));
-  
   parent_class = g_type_class_peek_parent (klass);
 
   object_class->finalize = xfburn_transcoder_gst_finalize;
@@ -222,7 +195,7 @@ xfburn_transcoder_gst_init (XfburnTranscoderGst * obj)
   /* if the mutex is locked, then we're not currently seeking
    * information from gst */
   g_mutex_init (&priv->gst_mutex);
-  g_mutex_lock (&priv->gst_mutex);
+  /* Actual lock acquired in prepare() and relased in finish() */
 
   priv->discoverer = gst_discoverer_new(GST_SECOND, NULL);
 }
@@ -235,7 +208,7 @@ xfburn_transcoder_gst_finalize (GObject * object)
   gst_element_set_state (priv->pipeline, GST_STATE_NULL);
 
   gst_object_unref (GST_OBJECT (priv->pipeline));
-  gst_object_unref (GST_OBJECT (priv->discoverer));
+  g_object_unref (G_OBJECT (priv->discoverer));
   priv->pipeline = NULL;
 
   G_OBJECT_CLASS (parent_class)->finalize (object);
@@ -492,19 +465,9 @@ bus_call (GstBus *bus, GstMessage *msg, gpointer data)
 
           if (strcmp (GST_OBJECT_NAME (GST_MESSAGE_SRC (msg)), "decoder") != 0)
             break;
-          
-          if (!g_mutex_trylock (&priv->gst_mutex)) {
-            g_critical ("Lock held by another thread, can't signal transcoding start!");
-            break;
-          } else {
-#if DEBUG_GST > 0
-            DBG ("Locked mutex to signal transcoding start");
-#endif
-          }
 
           priv->gst_done = TRUE;
           g_cond_signal (&priv->gst_cond);
-          g_mutex_unlock (&priv->gst_mutex);
           break;
       } /* switch of priv->state */
 
@@ -835,6 +798,8 @@ prepare (XfburnTranscoder *trans, GError **error)
   gboolean ret;
   gint64 end_time;
 
+  g_mutex_lock(&priv->gst_mutex);
+
   priv->tracks = g_slist_reverse (priv->tracks);
 
   priv->state = XFBURN_TRANSCODER_GST_STATE_TRANSCODE_START;
@@ -933,6 +898,8 @@ finish (XfburnTranscoder *trans)
   }
   */
   recreate_pipeline (gst);
+
+  g_mutex_unlock (&priv->gst_mutex);
 }
 
 
