@@ -35,6 +35,7 @@
 #include "xfburn-utils.h"
 #include "xfburn-settings.h"
 #include "xfburn-device-list.h"
+#include "xfburn-main.h"
 
 /***********/
 /* cursors */
@@ -45,10 +46,10 @@ xfburn_busy_cursor (GtkWidget * widget)
   GdkCursor *cursor;
 
   g_return_if_fail (widget != NULL);
-  cursor = gdk_cursor_new (GDK_WATCH);
+  cursor = gdk_cursor_new_for_display( gtk_widget_get_display(widget), GDK_WATCH);
   gdk_window_set_cursor (gtk_widget_get_parent_window (widget), cursor);
-  gdk_cursor_unref (cursor);
-  gdk_flush ();
+  g_object_unref (cursor);
+  gdk_display_flush (gtk_widget_get_display(widget));
 }
 
 void
@@ -56,7 +57,7 @@ xfburn_default_cursor (GtkWidget * widget)
 {
   g_return_if_fail (widget != NULL);
   gdk_window_set_cursor (gtk_widget_get_parent_window (widget), NULL);
-  gdk_flush ();
+  gdk_display_flush (gtk_widget_get_display(widget));
 }
 
 /*******************/
@@ -72,7 +73,7 @@ xfburn_humanreadable_filesize (guint64 size)
 
   if (!xfburn_settings_get_boolean ("human-readable-units", TRUE))
     return g_strdup_printf ("%lu B", (long unsigned int) size);
-  
+
   /* copied from GnomeBaker */
 
   while (human_size > 1024 && unit < 4) {
@@ -124,21 +125,26 @@ xfburn_browse_for_file (GtkEntry *entry, GtkWindow *parent)
 {
   GtkWidget *dialog;
   const gchar *text;
-  
+
   text = gtk_entry_get_text (entry);
 
-  dialog = gtk_file_chooser_dialog_new (_("Select command"), parent, GTK_FILE_CHOOSER_ACTION_SAVE, GTK_STOCK_CANCEL,
-                                        GTK_RESPONSE_CANCEL, GTK_STOCK_SAVE, GTK_RESPONSE_ACCEPT, NULL);
+  dialog = gtk_file_chooser_dialog_new (_("Select command"), parent, GTK_FILE_CHOOSER_ACTION_SAVE, "_Cancel",
+                                        GTK_RESPONSE_CANCEL, "document-save", GTK_RESPONSE_ACCEPT, NULL);
+
+  if(xfburn_main_has_initial_dir ()) {
+    gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (dialog), xfburn_main_get_initial_dir ());
+  }
+
   if (strlen (text) > 0)
     gtk_file_chooser_set_filename (GTK_FILE_CHOOSER (dialog), text);
-  
+
   if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_ACCEPT) {
     gchar *filename = NULL;
-    
+
     filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (dialog));
     gtk_entry_set_text (entry, filename);
     g_free (filename);
-  } 
+  }
 
   gtk_widget_destroy (dialog);
 }
@@ -168,7 +174,7 @@ xfburn_ask_yes_no (GtkMessageType type, const gchar *primary_text, const gchar *
     default:
       ok = FALSE;
   }
-  xfburn_busy_cursor (GTK_DIALOG (dialog)->vbox);
+  xfburn_busy_cursor (gtk_dialog_get_content_area(GTK_DIALOG (dialog)));
   gtk_widget_destroy (GTK_WIDGET (dialog));
 
   return ok;
@@ -185,12 +191,12 @@ xfburn_gtk_button_new_mixed (const gchar *stock_id, const gchar *label)
         button = gtk_button_new_with_mnemonic (label);
         if (stock_id != NULL) {
             /* create image widget */
-            image = gtk_image_new_from_stock (stock_id, GTK_ICON_SIZE_BUTTON);
+            image = gtk_image_new_from_icon_name (stock_id, GTK_ICON_SIZE_BUTTON);
             gtk_button_set_image (GTK_BUTTON (button), image);
         }
     } else {
         /* fall back to a stock button */
-        button = gtk_button_new_from_stock (stock_id);
+        button = gtk_button_new_with_label (stock_id);
     }
     return button;
 }
@@ -207,7 +213,7 @@ xfburn_capture_libburn_messages (void)
 {
   int ret;
 
-#ifdef DEBUG_LIBBURN 
+#ifdef DEBUG_LIBBURN
   ret = burn_msgs_set_severities ("NEVER", "DEBUG", libburn_msg_prefix);
 #else
   ret = burn_msgs_set_severities ("ALL", "NEVER", libburn_msg_prefix);
@@ -222,7 +228,7 @@ xfburn_console_libburn_messages (void)
 {
   int ret;
 
-#ifdef DEBUG_LIBBURN 
+#ifdef DEBUG_LIBBURN
   ret = burn_msgs_set_severities ("NEVER", "DEBUG", libburn_msg_prefix);
 #else
   ret = burn_msgs_set_severities ("NEVER", "FATAL", libburn_msg_prefix);
@@ -230,7 +236,7 @@ xfburn_console_libburn_messages (void)
 
   if (ret <= 0)
     g_warning ("Failed to set libburn message severities");
- 
+
 }
 
 int
@@ -275,3 +281,30 @@ xfburn_make_abosulet_file_list (gint count, gchar *filenames[])
 
   return list;
 }
+/* adding items to a toolbar*/
+void
+xfburn_add_button_to_toolbar(GtkToolbar *toolbar, const gchar *stock, const gchar *text, const gchar *action, const gchar *tooltip)
+{
+  GtkToolItem *item;
+  GtkWidget *icon;
+  GtkWidget *label;
+
+  label = gtk_label_new(text);
+  icon = gtk_image_new_from_icon_name (stock, 0);
+  item = gtk_tool_button_new(icon, text);
+  gtk_tool_item_set_tooltip_text(item, (tooltip == NULL) ? text : tooltip);
+  gtk_tool_button_set_label_widget(GTK_TOOL_BUTTON (item), label);
+  gtk_toolbar_insert(toolbar, item, -1);
+  gtk_actionable_set_action_name (GTK_ACTIONABLE (item), action);
+}
+
+/* creates a progress bar with the initial label set to text and with the label visible */
+GtkWidget *
+xfburn_create_progress_bar (const gchar *text)
+{
+  GtkProgressBar *pbar = GTK_PROGRESS_BAR (gtk_progress_bar_new ());
+  gtk_progress_bar_set_show_text (pbar, TRUE);
+  if (text != NULL && *text != '\0')
+    gtk_progress_bar_set_text (pbar, text);
+  return GTK_WIDGET (pbar);
+}
